// Java class com.proton.gopenpgp.crypto.KeyRing is a proxy for talking to a Go program.
//   gobind -lang=java -javapkg=com.proton.gopenpgp github.com/ProtonMail/gopenpgp/v2/crypto
//
// File is generated by gobind. Do not edit.
package com.proton.gopenpgp.crypto;

import go.Seq;

/**
 * KeyRing contains multiple private and public keys.
 */
public final class KeyRing implements Seq.Proxy {
	static { Crypto.touch(); }
	
	private final int refnum;
	
	@Override public final int incRefnum() {
	      Seq.incGoRef(refnum, this);
	      return refnum;
	}
	
	/**
	 * NewKeyRing creates a new KeyRing, empty if key is nil
	 */
	public KeyRing(Key key) {
		this.refnum = __NewKeyRing(key);
		Seq.trackGoRef(refnum, this);
	}
	
	private static native int __NewKeyRing(Key key);
	
	KeyRing(int refnum) { this.refnum = refnum; Seq.trackGoRef(refnum, this); }
	
	/**
	 * FirstKeyID as obtained from API to match salt
	 */
	public final native String getFirstKeyID();
	/**
	 * FirstKeyID as obtained from API to match salt
	 */
	public final native void setFirstKeyID(String v);
	
	/**
	 * --- Add keys to keyring
	 */
	public native void addKey(Key key) throws Exception;
	public native void clearPrivateParams();
	/**
	 * Copy creates a deep copy of the keyring
	 */
	public native KeyRing copy() throws Exception;
	/**
	 * CountDecryptionEntities returns the number of entities in the keyring
	 */
	public native long countDecryptionEntities();
	/**
	 * CountEntities returns the number of entities in the keyring
	 */
	public native long countEntities();
	/**
	 * Decrypt decrypts encrypted string using pgp keys, returning a PlainMessage
	* message    : The encrypted input as a PGPMessage
	* verifyKey  : Public key for signature verification (optional)
	* verifyTime : Time at verification (necessary only if verifyKey is not nil)
	
	When verifyKey is not provided, then verifyTime should be zero, and signature verification will be ignored
	 */
	public native PlainMessage decrypt(PGPMessage message, KeyRing verifyKey, long verifyTime) throws Exception;
	public native PlainMessage decryptAttachment(PGPSplitMessage message) throws Exception;
	/**
	 * DecryptMIMEMessage decrypts a MIME message.
	 */
	public native void decryptMIMEMessage(PGPMessage message, KeyRing verifyKey, MIMECallbacks callbacks, long verifyTime);
	/**
	 * DecryptSessionKey returns the decrypted session key from a binary encrypted session key packet.
	 */
	public native SessionKey decryptSessionKey(byte[] keyPacket) throws Exception;
	/**
	 * Encrypt encrypts a PlainMessage, outputs a PGPMessage.
	If an unlocked private key is also provided it will also sign the message.
	* message    : The plaintext input as a PlainMessage
	* privateKey : (optional) an unlocked private keyring to include signature in the message
	 */
	public native PGPMessage encrypt(PlainMessage message, KeyRing privateKey) throws Exception;
	public native PGPSplitMessage encryptAttachment(PlainMessage message, String fileName) throws Exception;
	/**
	 * EncryptSessionKey encrypts the session key with the unarmored
	publicKey and returns a binary public-key encrypted session key packet.
	 */
	public native byte[] encryptSessionKey(SessionKey sk) throws Exception;
	/**
	 * FirstKey returns a KeyRing with only the first key of the original one
	 */
	public native KeyRing firstKey() throws Exception;
	// skipped method KeyRing.GetIdentities with unsupported parameter or return types
	
	/**
	 * GetKey returns the n-th openpgp key contained in this KeyRing.
	 */
	public native Key getKey(long n) throws Exception;
	// skipped method KeyRing.GetKeyIDs with unsupported parameter or return types
	
	// skipped method KeyRing.GetKeys with unsupported parameter or return types
	
	public native AttachmentProcessor newLowMemoryAttachmentProcessor(long estimatedSize, String fileName) throws Exception;
	/**
	 * SignDetached generates and returns a PGPSignature for a given PlainMessage
	 */
	public native PGPSignature signDetached(PlainMessage message) throws Exception;
	/**
	 * VerifyDetached verifies a PlainMessage with embedded a PGPSignature
	and returns a SignatureVerificationError if fails
	 */
	public native void verifyDetached(PlainMessage message, PGPSignature signature, long verifyTime) throws Exception;
	@Override public boolean equals(Object o) {
		if (o == null || !(o instanceof KeyRing)) {
		    return false;
		}
		KeyRing that = (KeyRing)o;
		String thisFirstKeyID = getFirstKeyID();
		String thatFirstKeyID = that.getFirstKeyID();
		if (thisFirstKeyID == null) {
			if (thatFirstKeyID != null) {
			    return false;
			}
		} else if (!thisFirstKeyID.equals(thatFirstKeyID)) {
		    return false;
		}
		return true;
	}
	
	@Override public int hashCode() {
	    return java.util.Arrays.hashCode(new Object[] {getFirstKeyID()});
	}
	
	@Override public String toString() {
		StringBuilder b = new StringBuilder();
		b.append("KeyRing").append("{");
		b.append("FirstKeyID:").append(getFirstKeyID()).append(",");
		return b.append("}").toString();
	}
}

